@@ -199,6 +199,17 @@ package Net::BitTorrent::Torrent;
                  )
             );
         }
+        if (   ($args->{q[Client]})
+            && (blessed $args->{q[Client]})
+            && ($args->{q[Client]}->isa(q[Net::BitTorrent])))
+        {   foreach my $_node ($raw_data{refaddr $self}{q[nodes]}
+                               ? @{$raw_data{refaddr $self}{q[nodes]}}
+                               : ()
+                )
+            {   $args->{q[Client]}->_dht->add_node(
+                                    {ip => $_node->[0], port => $_node->[1]});
+            }
+        }
         $args->{q[Status]} ||= 0;
         $args->{q[Status]} ^= CHECKING if $args->{q[Status]} & CHECKING;
         $args->{q[Status]} ^= CHECKED  if $args->{q[Status]} & CHECKED;
@@ -1752,6 +1763,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Torrent.pm d8d71ee 2009-02-13 20:55:16Z sanko@cpan.org $
+=for svn $Id: Torrent.pm d3c97de 2009-09-12 04:31:46Z sanko@cpan.org $
 
 =cut
